@@ -2,7 +2,7 @@ package BioX::Wrapper::Gemini;
 
 use 5.008_005;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Moose;
 use File::Find::Rule;
@@ -147,11 +147,11 @@ Default is -c \$SNPEFF/snpEff.config -formatEff -classic GRCh37.75
 =cut
 
 has snpeff_opt => (
-     is => 'rw',
-     isa => 'Str',
-     required => 0,
-     default => '-c \$SNPEFF/snpEff.config -formatEff -classic GRCh37.75 ',
-     documentation => 'Snpeff run parameters. Default -c \$SNPEFF/snpEff.config -formatEff -classic GRCh37.75'
+    is => 'rw',
+    isa => 'Str',
+    required => 0,
+    default => "-c \$SNPEFF/snpEff.config -formatEff -classic GRCh37.75 ",
+    documentation => "Snpeff run parameters. Default -c \$SNPEFF/snpEff.config -formatEff -classic GRCh37.75",
 );
 
 =head2 ped
